@@ -22,16 +22,25 @@ async def message_callback(room: MatrixRoom, event: RoomMessageText) -> None:
         f"Message received in room {room.display_name}\n"
         f"{room.user_name(event.sender)} | {event.body}"
     )
+    is_group = len(room.users.keys()) > 2 or room.is_named
+    if 'Löwenherz' in room.display_name:
+        print("Löwenherz!")
+
+    if is_group and not room.is_named:
+        room_name = ', '.join([user.display_name for id, user in room.users.items() if id != room.own_user_id])
+    else:
+        room_name = room.display_name
+
     chat_info = {
         'ID': event.server_timestamp,
         'date': datetime.utcfromtimestamp(event.server_timestamp / 1000),
-        'type': 'Group' if room.is_group else 'User'
+        'type': 'Group' if is_group else 'User'
     }
-    if event.sender == User:  # I sent this message
-        if room.is_group or len(room.users) == 1:
+    if event.sender == room.own_user_id:  # I sent this message
+        if is_group:
             chat_info.update({
                 'to_id': room.room_id,
-                'to': room.name
+                'to': room_name
             })
         else:
             to_id = list(filter(lambda u: u != User, room.users))[0]
@@ -42,16 +51,15 @@ async def message_callback(room: MatrixRoom, event: RoomMessageText) -> None:
             })
 
     else:
-        from_id = list(filter(lambda u: u != User, room.users))[0]
-        from_user = room.users[from_id]
+        from_user = [user for u_id, user in room.users.items() if u_id == event.sender][0]
         chat_info.update({
             'from_id': from_user.user_id,
             'from': from_user.display_name
         })
-        if room.is_group:
+        if is_group:
             chat_info.update({
                 'to_id': room.room_id,
-                'to': room.name
+                'to': room_name
             })
     #if event.
     #chat_info['edit']
@@ -67,7 +75,7 @@ async def main() -> None:
     client_config = ClientConfig(store_sync_tokens=True)
     # If there are no previously-saved credentials, we'll use the password
     if not os.path.exists(CONFIG_FILE):
-        print("First time use. Did not find credential file. Asking for "
+        print("First time use. Did not find credential file. Using supplied "
               "homeserver, user, and password to create credential file.")
         if not (MATRIX_HS_URL.startswith("https://")
                 or MATRIX_HS_URL.startswith("http://")):
